Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Service Quotas.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Actions, Resources, and Condition Keys for Service Quotas - AWS Identity and Access Management

# Actions, Resources, and Condition Keys for Service Quotas

Service Quotas (service prefix: `servicequotas` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by Service Quotas
- Resource Types Defined by Service Quotas
- Condition Keys for Service Quotas

## Actions Defined by Service Quotas

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource Types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table .

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
AssociateServiceQuotaTemplate | Grants permission to associate the Service Quotas template with your organization | Write |  |  |
DeleteServiceQuotaIncreaseRequestFromTemplate | Grants permission to remove the specified service quota from the service quota template | Write |  |  |
DisassociateServiceQuotaTemplate | Grants permission to disassociate the Service Quotas template from your organization | Write |  |  |
GetAWSDefaultServiceQuota | Grants permission to return the details for the specified service quota, including the AWS default value | Read |  |  |
GetAssociationForServiceQuotaTemplate | Grants permission to retrieve the ServiceQuotaTemplateAssociationStatus value, which tells you if the Service Quotas template is associated with an organization | Read |  |  |
GetRequestedServiceQuotaChange | Grants permission to retrieve the details for a particular service quota increase request | Read |  |  |
GetServiceQuota | Grants permission to return the details for the specified service quota, including the applied value | Read |  |  |
GetServiceQuotaIncreaseRequestFromTemplate | Grants permission to retrieve the details for a service quota increase request from the service quota template | Read |  |  |
ListAWSDefaultServiceQuotas | Grants permission to list all default service quotas for the specified AWS service | Read |  |  |
ListRequestedServiceQuotaChangeHistory | Grants permission to request a list of the changes to quotas for a service | Read |  |  |
ListRequestedServiceQuotaChangeHistoryByQuota | Grants permission to request a list of the changes to specific service quotas | Read |  |  |
ListServiceQuotaIncreaseRequestsInTemplate | Grants permission to return a list of the service quota increase requests from the service quota template | Read |  |  |
ListServiceQuotas | Grants permission to list all service quotas for the specified AWS service, in that account, in that Region | Read |  |  |
ListServices | Grants permission to list the AWS services available in Service Quotas | Read |  |  |
PutServiceQuotaIncreaseRequestIntoTemplate | Grants permission to define and add a quota to the service quota template | Write | quota |  |
| servicequotas:service |
RequestServiceQuotaIncrease | Grants permission to submit the request for a service quota increase | Write | quota |  |
| servicequotas:service |

## Resource Types Defined by Service Quotas

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table .

Resource Types | ARN | Condition Keys
--- | --- | ---
quota | `arn:$ { Partition}:servicequotas:$ { Region}:$ { Account}:$ { ServiceCode}/$ { QuotaCode}` |

## Condition Keys for Service Quotas

Service Quotas defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table .

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference .

Condition Keys | Description | Type
--- | --- | ---
servicequotas:service | Filters or restricts access to a specified AWS service | string

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.